<div align="center">
  <img src="https://imgur.com/FgQvEZ2" width="600" /><br><br>
</div>

# savvihub-client

A Command line interface and library for SavviHub


## Features
- A Command line interface to communicate with SavviHub
- Python SDK to log the experiment

## Quickstart
```shell
pip install savvihub-client
```